@@ -8,9 +8,9 @@ var os = require('os');
  * If so, use it to grab the config
  */
 
-global.endpoint = "127.0.0.1";
-global.port = 8500;
-global.secure = false;
+global.endpoint = process.env.CONSUL_ENDPOINT || "127.0.0.1";
+global.port = process.env.CONSUL_PORT || 8500;
+global.secure = process.env.CONSUL_SECURE || false;
 global.config_key = "git2consul/config"
 for (var i=2; i<process.argv.length; ++i) {
   if(process.argv[i] === '-s' || process.argv[i] === '--secure') global.secure = true
@@ -106,4 +106,3 @@ config_reader.read({'key': 'git2consul/config'}, function(err, config) {
   });
 
 });
-
